@@ -3,9 +3,6 @@
 """
 Collection of helper methods for data module
 
-+ extract_dict:        extract key-value pairs with values given indexes.
-+ get_unique_unsorted: return a unique unsorted list
-
 @author: baihan
 """
 
