@@ -15,7 +15,6 @@ import pyrsa.rdm as rsr
 import pyrsa as rsa
 
 
-
 class TestRDM(unittest.TestCase):
 
     def test_rdm3d_init(self):
@@ -161,6 +160,56 @@ class TestRDM(unittest.TestCase):
         self.assertEqual(rdms_sample.n_rdm, 3)
         assert_array_equal(rdms_sample.dissimilarities[0], dis[3])
 
+    def test_rdm_len(self):
+        n_rdm, n_cond = 7, 10
+        dis = np.zeros((n_rdm, n_cond, n_cond))
+        rdms = rsr.RDMs(dissimilarities=dis,
+                        pattern_descriptors={
+                            'type': np.array(list(range(n_cond)))},
+                        dissimilarity_measure='Euclidean',
+                        descriptors={'subj': range(n_rdm)})
+        self.assertEqual(len(rdms), n_rdm)
+
+    def test_rdm_idx_len_is_1(self):
+        n_rdm, n_cond = 7, 10
+        dis = np.zeros((n_rdm, n_cond, n_cond))
+        rdms = rsr.RDMs(dissimilarities=dis,
+                        pattern_descriptors={
+                            'type': np.array(list(range(n_cond)))},
+                        dissimilarity_measure='Euclidean',
+                        descriptors={'subj': range(n_rdm)})
+        self.assertEqual(len(rdms[0]), 1)
+
+    def test_rdm_subset_len(self):
+        subset_idxs = [0, 1, 2]
+        dis = np.zeros((8, 10))
+        mes = "Euclidean"
+        des = {'subj': 0}
+        rdm_des = {'session': np.array([0, 1, 2, 3, 4, 5, 6, 7])}
+        rdms = rsr.RDMs(dissimilarities=dis,
+                        rdm_descriptors=rdm_des,
+                        dissimilarity_measure=mes,
+                        descriptors=des)
+        rdms_subset = rdms.subset('session', np.array(subset_idxs))
+        self.assertEqual(len(rdms_subset), len(subset_idxs))
+
+    def test_rdm_iter(self):
+        dis = np.zeros((8, 10))
+        mes = "Euclidean"
+        des = {'subj': 0}
+        rdm_des = {'session': np.array([0, 1, 2, 2, 4, 5, 6, 7])}
+        rdms = rsr.RDMs(dissimilarities=dis,
+                        rdm_descriptors=rdm_des,
+                        dissimilarity_measure=mes,
+                        descriptors=des)
+        i = 0
+        for rdm in rdms:
+            self.assertIsInstance(rdm, rsr.RDMs)
+            self.assertEqual(len(rdm), 1)
+            assert_array_equal(rdm.dissimilarities, rdms[i].dissimilarities)
+            i += 1
+        self.assertEqual(i, rdms.n_rdm)
+
     def test_rank_transform(self):
         from pyrsa.rdm import rank_transform
         dis = np.zeros((8, 10))
@@ -216,7 +265,8 @@ class TestRDM(unittest.TestCase):
         from pyrsa.rdm import get_categorical_rdm
         category_vector = [1, 2, 2, 3]
         rdm = get_categorical_rdm(category_vector)
-        np.testing.assert_array_almost_equal(rdm.dissimilarities,
+        np.testing.assert_array_almost_equal(
+            rdm.dissimilarities,
             np.array([[1., 1., 1., 0., 1., 1.]]))
 
     def test_reorder(self):
@@ -233,7 +283,8 @@ class TestRDM(unittest.TestCase):
             pattern_descriptors=dict(conds=conds)
         )
         conds_ordered = ['b', 'a', 'c', 'd']
-        new_order = [conds.index(l) for l in conds_ordered]
+        new_order = [conds.index(cond_idx)
+                     for cond_idx in conds_ordered]
         rdm_reordered = rdm[np.ix_(new_order, new_order)]
         rdms.reorder(new_order)
         assert_array_equal(
@@ -313,6 +364,7 @@ class TestCalcRDM(unittest.TestCase):
             channel_descriptors=dict(feats=['v1', 'v2', 'v3'])
         )
 
+
     def test_calc_euclid_nconds(self):
         rdm = rsr.calc_rdm(self.test_data, descriptor='conds',
                            method='euclidean')
@@ -448,6 +500,101 @@ class TestCalcRDM(unittest.TestCase):
         assert rdm.n_cond == 6
 
 
+class TestCalcRDMMovie(unittest.TestCase):
+
+    def setUp(self):
+        measurements_time = np.random.rand(20, 5, 15)
+        tim_des = {'time': np.linspace(0,200, 15)}
+
+        des = {'session': 0, 'subj': 0}
+        obs_des = {'conds': np.array([0, 0, 1, 1, 2, 2, 2, 3, 4, 5,
+                                      0, 0, 1, 1, 2, 2, 2, 3, 4, 5]),
+                   'fold': np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                                     1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
+                   }
+        obs_balanced = {'conds': np.array([0, 0, 1, 1, 2, 2, 3, 3, 4, 4,
+                                           0, 0, 1, 1, 2, 2, 3, 3, 4, 4]),
+                        'fold': np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                                          1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
+                        }
+        chn_des = {'rois': np.array(['sensor1', 'sensor2', 'sensor3', 'sensor5', 'sensor5'])}
+
+
+        self.test_data_time = rsa.data.TemporalDataset(measurements=measurements_time,
+                               descriptors=des,
+                               obs_descriptors=obs_des,
+                               channel_descriptors=chn_des,
+                               time_descriptors=tim_des
+                               )
+        self.test_data_time_balanced = rsa.data.TemporalDataset(measurements=measurements_time,
+                               descriptors=des,
+                               obs_descriptors=obs_balanced,
+                               channel_descriptors=chn_des,
+                               time_descriptors=tim_des
+                               )
+
+    def test_calc_rdm_movie_mahalanobis(self):
+        rdm = rsr.calc_rdm_movie(self.test_data_time, descriptor='conds',
+                           method='mahalanobis', time_descriptor = 'time')
+        assert rdm.n_cond == 6
+        assert len([r for r in rdm]) == 15
+        assert rdm.rdm_descriptors['time'][0] == 0.0
+
+    def test_calc_rdm_movie_euclidean(self):
+        rdm = rsr.calc_rdm_movie(self.test_data_time, descriptor='conds',
+                           method='euclidean', time_descriptor = 'time')
+        assert rdm.n_cond == 6
+        assert len([r for r in rdm]) == 15
+        assert rdm.rdm_descriptors['time'][0] == 0.0
+
+    def test_calc_rdm_movie_correlation(self):
+        rdm = rsr.calc_rdm_movie(self.test_data_time, descriptor='conds',
+                           method='correlation', time_descriptor = 'time')
+        assert rdm.n_cond == 6
+        assert len([r for r in rdm]) == 15
+        assert rdm.rdm_descriptors['time'][0] == 0.0
+
+    def test_calc_rdm_movie_crossnobis(self):
+        rdm = rsr.calc_rdm_movie(self.test_data_time, descriptor='conds',
+                           method='crossnobis', time_descriptor = 'time',
+                                      cv_descriptor='fold')
+        assert rdm.n_cond == 6
+        assert len([r for r in rdm]) == 15
+        assert rdm.rdm_descriptors['time'][0] == 0.0
+
+    def test_calc_rdm_movie_crossnobis_no_descriptors(self):
+        rdm = rsr.calc_rdm_crossnobis(self.test_data_time_balanced,
+                                      descriptor='conds')
+        assert rdm.n_cond == 5
+
+    def test_calc_rdm_movie_crossnobis_noise(self):
+        noise = np.random.randn(10, 5)
+        noise = np.matmul(noise.T, noise)
+        rdm = rsr.calc_rdm_crossnobis(self.test_data_time_balanced,
+                                      descriptor='conds',
+                                      noise=noise)
+        assert rdm.n_cond == 5
+
+    def test_calc_rdm_movie_rdm_movie_poisson(self):
+        noise = np.random.randn(10, 5)
+        noise = np.matmul(noise.T, noise)
+        rdm = rsr.calc_rdm_movie(self.test_data_time_balanced,
+                                      method='poisson',
+                                      descriptor='conds',
+                                      noise=noise)
+        assert rdm.n_cond == 5
+
+    def test_calc_rdm_movie_binned(self):
+        time = self.test_data_time.time_descriptors['time']
+        bins = np.reshape(time, [5, 3])
+        rdm = rsr.calc_rdm_movie(self.test_data_time, descriptor='conds',
+                           method='mahalanobis', time_descriptor = 'time',
+                           bins=bins)
+        assert rdm.n_cond == 6
+        assert len([r for r in rdm]) == 5
+        assert rdm.rdm_descriptors['time'][0] == np.mean(time[:3])
+
+
 class TestCompareRDM(unittest.TestCase):
 
     def setUp(self):
@@ -544,9 +691,9 @@ class TestCompareRDM(unittest.TestCase):
         d2 = d2 - np.mean(d2, 1, keepdims=True)
         for i in range(result_loop.shape[0]):
             for j in range(result_loop.shape[1]):
-                result_loop[i,j] = (np.sum(d1[i] * d2[j])
-                                    / np.sqrt(np.sum(d1[i] * d1[i]))
-                                    / np.sqrt(np.sum(d2[j] * d2[j])))
+                result_loop[i, j] = (np.sum(d1[i] * d2[j])
+                                     / np.sqrt(np.sum(d1[i] * d1[i]))
+                                     / np.sqrt(np.sum(d2[j] * d2[j])))
         assert_array_almost_equal(result, result_loop)
 
     def test_compare_spearman(self):
